@@ -1,14 +1,8 @@
 require 'puppet'
 
 Puppet::Type.type(:vs_bridge).provide(:ovs) do
-  commands :vsctl     => 'ovs-vsctl'
-  if Facter.value(:operatingsystem) == 'FreeBSD'
-    commands :ifconfig  => 'ifconfig'
-  elsif Facter.value(:operatingsystem) == 'Solaris'
-    commands :ipadm  => '/usr/sbin/ipadm'
-  else
-    commands :ip  => 'ip'
-  end
+  commands :vsctl => 'ovs-vsctl'
+  commands :ip    => 'ip'
 
   def exists?
     vsctl("br-exists", @resource[:name])
@@ -18,23 +12,12 @@ Puppet::Type.type(:vs_bridge).provide(:ovs) do
 
   def create
     vsctl('add-br', @resource[:name])
-    if Facter.value(:operatingsystem) == 'FreeBSD'
-      vsctl('set','bridge',@resource[:name],'datapath_type=netdev')
-      ifconfig(@resource[:name],'up')
-    elsif Facter.value(:operatingsystem) == 'Solaris'
-      ipadm('create-ip', @resource[:name])
-    else
-      ip('link', 'set', 'dev', @resource[:name], 'up')
-    end
+    ip('link', 'set', 'dev', @resource[:name], 'up')
     external_ids = @resource[:external_ids] if @resource[:external_ids]
   end
 
   def destroy
-    if Facter.value(:operatingsystem) == 'FreeBSD'
-      ifconfig(@resource[:name],'down')
-    else
-      ip('link', 'set', 'dev', @resource[:name], 'down')
-    end
+    ip('link', 'set', 'dev', @resource[:name], 'down')
     vsctl('del-br', @resource[:name])
   end
 
